@@ -191,4 +191,4 @@ class UploaderDB(UploaderDBBase, ABC):
             cur_file += 1
 
         if self.table_to_optimize is not None:
-            self.__optimize_table_ch(table=self.table_to_optimize, ch_client=ch_client, add=" deduplicate")
+            self.__optimize_table_ch(table=self.table_to_optimize, ch_client=ch_client, add=" final deduplicate")
