@@ -16,14 +16,15 @@ class UploaderDB(UploaderDBBase, ABC):
     """
 
     def __init__(
-        self,
-        s3_client,
-        sql_credentials,
-        entity,
-        table_name,
-        files_in_upload=5,
-        json_columns=None,
-        api_version=4,
+            self,
+            s3_client,
+            sql_credentials,
+            entity,
+            table_name,
+            files_in_upload=5,
+            full_copy=False,
+            json_columns=None,
+            api_version=4,
     ):
         """
         :param s3_client: s3 client from talenttech-oss library
@@ -45,17 +46,18 @@ class UploaderDB(UploaderDBBase, ABC):
         )
 
         self.logger = logging.getLogger(__class__.__name__)
+        self.full_copy = full_copy
         self.db = "vertica"
 
     def load_s3_to_db(self):
         """the main method for running class"""
         with VerticaConnector(
-            user=self.sql_credentials["user"],
-            password=self.sql_credentials["password"],
-            database=self.sql_credentials["database"],
-            vertica_configs=self.sql_credentials["vertica_configs"],
-            sec_to_recconect=2,
-            count_retries=1,
+                user=self.sql_credentials["user"],
+                password=self.sql_credentials["password"],
+                database=self.sql_credentials["database"],
+                vertica_configs=self.sql_credentials["vertica_configs"],
+                sec_to_recconect=2,
+                count_retries=1,
         ) as v_connector:
             data = []
             cur_file = 1
@@ -81,6 +83,14 @@ class UploaderDB(UploaderDBBase, ABC):
                     )
                 raise ModuleNotFoundError("Table not found exception") from exc
 
+            if self.full_copy and len(paths) > 0:
+                table_common_suffix = get_date_str(paths[0])
+                v_connector.create_staging_table(table_name=self.table_name,
+                                                 schema=self.sql_credentials["schema"],
+                                                 staging_schema=self.sql_credentials["staging_schema"],
+                                                 table_suffix=table_common_suffix
+                                                 )
+
             for file_path in paths:
                 self.logger.info("Loading data from the file %s", file_path)
 
@@ -92,15 +102,31 @@ class UploaderDB(UploaderDBBase, ABC):
                     data = self.update_data(
                         data=data, table_name=self.table_name, db=self.db
                     )
-                    v_connector.insert_merge_vertica(
-                        table_name=self.table_name,
-                        schema=self.sql_credentials["schema"],
-                        staging_schema=self.sql_credentials["staging_schema"],
-                        data=data,
-                        key_fields=[self.unique_column],
-                        staging_table_suffix=get_date_str(file_path),
-                    )
+                    if not self.full_copy:
+                        v_connector.insert_merge_vertica(
+                            table_name=self.table_name,
+                            schema=self.sql_credentials["schema"],
+                            staging_schema=self.sql_credentials["staging_schema"],
+                            data=data,
+                            key_fields=[self.unique_column],
+                            staging_table_suffix=get_date_str(file_path),
+                        )
+                    else:
+                        v_connector.insert(
+                            table_name=self.table_name,
+                            schema=self.sql_credentials["staging_schema"],
+                            data=data,
+                            table_suffix=table_common_suffix
+                        )
                     self.uploaded_rows += len(data)
                     self.log_status(cty_upload=len(data))
                     data = []
                 cur_file += 1
+
+            if self.full_copy:
+                v_connector.reload_main_table(
+                    table_name=self.table_name,
+                    schema=self.sql_credentials["schema"],
+                    staging_schema=self.sql_credentials["staging_schema"],
+                    table_suffix=table_common_suffix
+                )
